<?php
/**
 * Plugin Name: User Roles and Capabilities Display
 * Plugin URI: https://webyblog.es/
 * Description: Muestra una lista de roles de usuario y sus capacidades activas en WordPress mediante un shortcode [display_user_roles].
 * Version: 1.0.1
 * Author: Juan Luis Martel
 * Author URI: https://webyblog.es/
 * License: GPL2
 */


// Evita la ejecución directa del script 
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Shortcode para mostrar los roles de usuario y sus capacidades [display_user_roles]
 */
function jlmr_display_user_roles_and_capabilities() {
	ob_start(); // Iniciar buffer de salida

	// Obtener todos los roles de usuario
	$roles = wp_roles()->roles;

	// Iniciar HTML
	echo '<div class="jlmr-roles-display">';

	foreach ( $roles as $role_key => $role_info ) {
		echo '<div class="jlmr-role">';
		echo '<h2>' . esc_html( $role_info['name'] ) . ' (' . esc_html( $role_key ) . ')</h2>'; // Muestra el nombre y el slug del rol
		echo '<ul>';

		// Listar capacidades activas
		foreach ( $role_info['capabilities'] as $cap => $value ) {
			if ( $value ) { // Solo mostrar capacidades activas
				echo '<li>' . esc_html( $cap ) . '</li>';
			}
		}

		echo '</ul>';
		echo '</div>';
	}

	echo '</div>';

	return ob_get_clean(); // Devolver el contenido del buffer
}

// Registrar el shortcode [display_user_roles]
add_shortcode( 'display_user_roles', 'jlmr_display_user_roles_and_capabilities' );

